/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtNetwork.h"

#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qsslsocket.sip"
#include <qsslsocket.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"

#line 28 "sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qsslerror.sip"
#include <qsslerror.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 28 "sip/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 42 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 67 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qocspresponse.sip"
#include <qocspresponse.h>
#line 45 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 48 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qssl.sip"
#include <qssl.h>
#line 51 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 54 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qsslcertificate.sip"
#include <qsslcertificate.h>
#line 57 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 26 "sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 60 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qabstractsocket.sip"
#include <qabstractsocket.h>
#line 63 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 26 "sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 66 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qsslconfiguration.sip"
#include <qsslconfiguration.h>
#line 69 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qsslpresharedkeyauthenticator.sip"
#include <qsslpresharedkeyauthenticator.h>
#line 72 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 26 "sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 75 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 78 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qsslcipher.sip"
#include <qsslcipher.h>
#line 81 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qsslkey.sip"
#include <qsslkey.h>
#line 84 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 30 "sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 87 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 166 "sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 90 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qhostaddress.sip"
#include <qhostaddress.h>
#line 93 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qabstractsocket.sip"
#include <qabstractsocket.h>
#line 96 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qabstractsocket.sip"
#include <qabstractsocket.h>
#line 99 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qnetworkproxy.sip"
#include <qnetworkproxy.h>
#line 102 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qauthenticator.sip"
#include <qauthenticator.h>
#line 105 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 110 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 26 "sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 113 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 26 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 116 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 247 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 119 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 235 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 122 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 125 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 149 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 128 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 131 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 26 "sip/QtCore/qthread.sip"
#include <qthread.h>
#line 134 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 137 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 26 "sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 140 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 143 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"


class sipQSslSocket : public  ::QSslSocket
{
public:
    sipQSslSocket( ::QObject*);
    virtual ~sipQSslSocket();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void resume() SIP_OVERRIDE;
     ::QVariant socketOption( ::QAbstractSocket::SocketOption) SIP_OVERRIDE;
    void setSocketOption( ::QAbstractSocket::SocketOption,const  ::QVariant&) SIP_OVERRIDE;
    bool waitForDisconnected(int) SIP_OVERRIDE;
    bool waitForConnected(int) SIP_OVERRIDE;
     ::qintptr socketDescriptor() const SIP_OVERRIDE;
    bool setSocketDescriptor( ::qintptr, ::QAbstractSocket::SocketState, ::QIODevice::OpenMode) SIP_OVERRIDE;
    void setReadBufferSize( ::qint64) SIP_OVERRIDE;
    void disconnectFromHost() SIP_OVERRIDE;
    void connectToHost(const  ::QString&, ::quint16, ::QIODevice::OpenMode, ::QAbstractSocket::NetworkLayerProtocol) SIP_OVERRIDE;
    void disconnectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent( ::QEvent*) SIP_OVERRIDE;
    void childEvent( ::QChildEvent*) SIP_OVERRIDE;
    void timerEvent( ::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter( ::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event( ::QEvent*) SIP_OVERRIDE;
    bool isSequential() const SIP_OVERRIDE;
    bool open( ::QIODevice::OpenMode) SIP_OVERRIDE;
    void close() SIP_OVERRIDE;
     ::qint64 pos() const SIP_OVERRIDE;
     ::qint64 size() const SIP_OVERRIDE;
    bool seek( ::qint64) SIP_OVERRIDE;
    bool atEnd() const SIP_OVERRIDE;
    bool reset() SIP_OVERRIDE;
     ::qint64 bytesAvailable() const SIP_OVERRIDE;
     ::qint64 bytesToWrite() const SIP_OVERRIDE;
    bool canReadLine() const SIP_OVERRIDE;
    bool waitForReadyRead(int) SIP_OVERRIDE;
    bool waitForBytesWritten(int) SIP_OVERRIDE;
     ::qint64 readData(char*, ::qint64) SIP_OVERRIDE;
     ::qint64 readLineData(char*, ::qint64) SIP_OVERRIDE;
     ::qint64 writeData(const char*,PY_LONG_LONG) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQSslSocket(const sipQSslSocket &);
    sipQSslSocket &operator = (const sipQSslSocket &);

    char sipPyMethods[33];
};

sipQSslSocket::sipQSslSocket( ::QObject*a0):  ::QSslSocket(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQSslSocket::~sipQSslSocket()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQSslSocket::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtNetwork_qt_metaobject(sipPySelf,sipType_QSslSocket);

    return  ::QSslSocket::metaObject();
}

int sipQSslSocket::qt_metacall(QMetaObject::Call _c,int _id,void **_a)
{
    _id =  ::QSslSocket::qt_metacall(_c,_id,_a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtNetwork_qt_metacall(sipPySelf,sipType_QSslSocket,_c,_id,_a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQSslSocket::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtNetwork_qt_metacast(sipPySelf, sipType_QSslSocket, _clname, &sipCpp) ? sipCpp :  ::QSslSocket::qt_metacast(_clname));
}

void sipQSslSocket::resume()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[0],sipPySelf,SIP_NULLPTR,sipName_resume);

    if (!sipMeth)
    {
         ::QSslSocket::resume();
        return;
    }

    extern void sipVH_QtNetwork_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtNetwork_13(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::QVariant sipQSslSocket::socketOption( ::QAbstractSocket::SocketOption a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[1],sipPySelf,SIP_NULLPTR,sipName_socketOption);

    if (!sipMeth)
        return  ::QSslSocket::socketOption(a0);

    extern  ::QVariant sipVH_QtNetwork_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QAbstractSocket::SocketOption);

    return sipVH_QtNetwork_27(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSslSocket::setSocketOption( ::QAbstractSocket::SocketOption a0,const  ::QVariant& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[2],sipPySelf,SIP_NULLPTR,sipName_setSocketOption);

    if (!sipMeth)
    {
         ::QSslSocket::setSocketOption(a0,a1);
        return;
    }

    extern void sipVH_QtNetwork_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QAbstractSocket::SocketOption,const  ::QVariant&);

    sipVH_QtNetwork_26(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQSslSocket::waitForDisconnected(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[3],sipPySelf,SIP_NULLPTR,sipName_waitForDisconnected);

    if (!sipMeth)
        return  ::QSslSocket::waitForDisconnected(a0);

    extern bool sipVH_QtNetwork_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtNetwork_17(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQSslSocket::waitForConnected(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[4],sipPySelf,SIP_NULLPTR,sipName_waitForConnected);

    if (!sipMeth)
        return  ::QSslSocket::waitForConnected(a0);

    extern bool sipVH_QtNetwork_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtNetwork_17(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

 ::qintptr sipQSslSocket::socketDescriptor() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[5]),sipPySelf,SIP_NULLPTR,sipName_socketDescriptor);

    if (!sipMeth)
        return  ::QSslSocket::socketDescriptor();

    extern  ::qintptr sipVH_QtNetwork_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_25(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQSslSocket::setSocketDescriptor( ::qintptr a0, ::QAbstractSocket::SocketState a1, ::QIODevice::OpenMode a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[6],sipPySelf,SIP_NULLPTR,sipName_setSocketDescriptor);

    if (!sipMeth)
        return  ::QSslSocket::setSocketDescriptor(a0,a1,a2);

    extern bool sipVH_QtNetwork_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::qintptr, ::QAbstractSocket::SocketState, ::QIODevice::OpenMode);

    return sipVH_QtNetwork_24(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQSslSocket::setReadBufferSize( ::qint64 a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[7],sipPySelf,SIP_NULLPTR,sipName_setReadBufferSize);

    if (!sipMeth)
    {
         ::QSslSocket::setReadBufferSize(a0);
        return;
    }

    extern void sipVH_QtNetwork_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::qint64);

    sipVH_QtNetwork_23(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSslSocket::disconnectFromHost()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[8],sipPySelf,SIP_NULLPTR,sipName_disconnectFromHost);

    if (!sipMeth)
    {
         ::QSslSocket::disconnectFromHost();
        return;
    }

    extern void sipVH_QtNetwork_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtNetwork_13(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQSslSocket::connectToHost(const  ::QString& a0, ::quint16 a1, ::QIODevice::OpenMode a2, ::QAbstractSocket::NetworkLayerProtocol a3)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[9],sipPySelf,SIP_NULLPTR,sipName_connectToHost);

    if (!sipMeth)
    {
         ::QSslSocket::connectToHost(a0,a1,a2,a3);
        return;
    }

    extern void sipVH_QtNetwork_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QString&, ::quint16, ::QIODevice::OpenMode, ::QAbstractSocket::NetworkLayerProtocol);

    sipVH_QtNetwork_21(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

void sipQSslSocket::disconnectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[10],sipPySelf,SIP_NULLPTR,sipName_disconnectNotify);

    if (!sipMeth)
    {
         ::QSslSocket::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtNetwork_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtNetwork_0(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSslSocket::connectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[11],sipPySelf,SIP_NULLPTR,sipName_connectNotify);

    if (!sipMeth)
    {
         ::QSslSocket::connectNotify(a0);
        return;
    }

    extern void sipVH_QtNetwork_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtNetwork_0(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSslSocket::customEvent( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[12],sipPySelf,SIP_NULLPTR,sipName_customEvent);

    if (!sipMeth)
    {
         ::QSslSocket::customEvent(a0);
        return;
    }

    extern void sipVH_QtNetwork_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    sipVH_QtNetwork_1(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSslSocket::childEvent( ::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[13],sipPySelf,SIP_NULLPTR,sipName_childEvent);

    if (!sipMeth)
    {
         ::QSslSocket::childEvent(a0);
        return;
    }

    extern void sipVH_QtNetwork_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QChildEvent*);

    sipVH_QtNetwork_2(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSslSocket::timerEvent( ::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[14],sipPySelf,SIP_NULLPTR,sipName_timerEvent);

    if (!sipMeth)
    {
         ::QSslSocket::timerEvent(a0);
        return;
    }

    extern void sipVH_QtNetwork_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QTimerEvent*);

    sipVH_QtNetwork_3(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQSslSocket::eventFilter( ::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[15],sipPySelf,SIP_NULLPTR,sipName_eventFilter);

    if (!sipMeth)
        return  ::QSslSocket::eventFilter(a0,a1);

    extern bool sipVH_QtNetwork_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QObject*, ::QEvent*);

    return sipVH_QtNetwork_4(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQSslSocket::event( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[16],sipPySelf,SIP_NULLPTR,sipName_event);

    if (!sipMeth)
        return  ::QSslSocket::event(a0);

    extern bool sipVH_QtNetwork_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    return sipVH_QtNetwork_5(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQSslSocket::isSequential() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[17]),sipPySelf,SIP_NULLPTR,sipName_isSequential);

    if (!sipMeth)
        return  ::QSslSocket::isSequential();

    extern bool sipVH_QtNetwork_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_18(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQSslSocket::open( ::QIODevice::OpenMode a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[18],sipPySelf,SIP_NULLPTR,sipName_open);

    if (!sipMeth)
        return  ::QSslSocket::open(a0);

    extern bool sipVH_QtNetwork_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QIODevice::OpenMode);

    return sipVH_QtNetwork_20(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSslSocket::close()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[19],sipPySelf,SIP_NULLPTR,sipName_close);

    if (!sipMeth)
    {
         ::QSslSocket::close();
        return;
    }

    extern void sipVH_QtNetwork_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtNetwork_13(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::qint64 sipQSslSocket::pos() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[20]),sipPySelf,SIP_NULLPTR,sipName_pos);

    if (!sipMeth)
        return  ::QSslSocket::pos();

    extern  ::qint64 sipVH_QtNetwork_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_10(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::qint64 sipQSslSocket::size() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[21]),sipPySelf,SIP_NULLPTR,sipName_size);

    if (!sipMeth)
        return  ::QSslSocket::size();

    extern  ::qint64 sipVH_QtNetwork_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_10(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQSslSocket::seek( ::qint64 a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[22],sipPySelf,SIP_NULLPTR,sipName_seek);

    if (!sipMeth)
        return  ::QSslSocket::seek(a0);

    extern bool sipVH_QtNetwork_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::qint64);

    return sipVH_QtNetwork_19(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQSslSocket::atEnd() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[23]),sipPySelf,SIP_NULLPTR,sipName_atEnd);

    if (!sipMeth)
        return  ::QSslSocket::atEnd();

    extern bool sipVH_QtNetwork_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_18(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQSslSocket::reset()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[24],sipPySelf,SIP_NULLPTR,sipName_reset);

    if (!sipMeth)
        return  ::QSslSocket::reset();

    extern bool sipVH_QtNetwork_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_18(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::qint64 sipQSslSocket::bytesAvailable() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[25]),sipPySelf,SIP_NULLPTR,sipName_bytesAvailable);

    if (!sipMeth)
        return  ::QSslSocket::bytesAvailable();

    extern  ::qint64 sipVH_QtNetwork_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_10(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::qint64 sipQSslSocket::bytesToWrite() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[26]),sipPySelf,SIP_NULLPTR,sipName_bytesToWrite);

    if (!sipMeth)
        return  ::QSslSocket::bytesToWrite();

    extern  ::qint64 sipVH_QtNetwork_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_10(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQSslSocket::canReadLine() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[27]),sipPySelf,SIP_NULLPTR,sipName_canReadLine);

    if (!sipMeth)
        return  ::QSslSocket::canReadLine();

    extern bool sipVH_QtNetwork_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_18(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQSslSocket::waitForReadyRead(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[28],sipPySelf,SIP_NULLPTR,sipName_waitForReadyRead);

    if (!sipMeth)
        return  ::QSslSocket::waitForReadyRead(a0);

    extern bool sipVH_QtNetwork_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtNetwork_17(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQSslSocket::waitForBytesWritten(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[29],sipPySelf,SIP_NULLPTR,sipName_waitForBytesWritten);

    if (!sipMeth)
        return  ::QSslSocket::waitForBytesWritten(a0);

    extern bool sipVH_QtNetwork_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtNetwork_17(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

 ::qint64 sipQSslSocket::readData(char*a0, ::qint64 a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[30],sipPySelf,SIP_NULLPTR,sipName_readData);

    if (!sipMeth)
        return  ::QSslSocket::readData(a0,a1);

    extern  ::qint64 sipVH_QtNetwork_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, char*, ::qint64);

    return sipVH_QtNetwork_16(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

 ::qint64 sipQSslSocket::readLineData(char*a0, ::qint64 a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[31],sipPySelf,SIP_NULLPTR,sipName_readLineData);

    if (!sipMeth)
        return  ::QSslSocket::readLineData(a0,a1);

    extern  ::qint64 sipVH_QtNetwork_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, char*, ::qint64);

    return sipVH_QtNetwork_15(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

 ::qint64 sipQSslSocket::writeData(const char*a0,PY_LONG_LONG a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[32],sipPySelf,SIP_NULLPTR,sipName_writeData);

    if (!sipMeth)
        return  ::QSslSocket::writeData(a0,a1);

    extern  ::qint64 sipVH_QtNetwork_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const char*,PY_LONG_LONG);

    return sipVH_QtNetwork_14(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}


PyDoc_STRVAR(doc_QSslSocket_connectToHostEncrypted, "connectToHostEncrypted(self, str, int, mode: Union[QIODevice.OpenMode, QIODevice.OpenModeFlag] = QIODevice.ReadWrite, protocol: QAbstractSocket.NetworkLayerProtocol = QAbstractSocket.AnyIPProtocol)\n"
"connectToHostEncrypted(self, str, int, str, mode: Union[QIODevice.OpenMode, QIODevice.OpenModeFlag] = QIODevice.ReadWrite, protocol: QAbstractSocket.NetworkLayerProtocol = QAbstractSocket.AnyIPProtocol)");

extern "C" {static PyObject *meth_QSslSocket_connectToHostEncrypted(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_connectToHostEncrypted(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::quint16 a1;
         ::QIODevice::OpenMode a2def = QIODevice::ReadWrite;
         ::QIODevice::OpenMode* a2 = &a2def;
        int a2State = 0;
         ::QAbstractSocket::NetworkLayerProtocol a3 = QAbstractSocket::AnyIPProtocol;
         ::QSslSocket *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_mode,
            sipName_protocol,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1t|J1E", &sipSelf, sipType_QSslSocket, &sipCpp, sipType_QString,&a0, &a0State, &a1, sipType_QIODevice_OpenMode, &a2, &a2State, sipType_QAbstractSocket_NetworkLayerProtocol, &a3))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->connectToHostEncrypted(*a0,a1,*a2,a3);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(a2,sipType_QIODevice_OpenMode,a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QString* a0;
        int a0State = 0;
         ::quint16 a1;
        const  ::QString* a2;
        int a2State = 0;
         ::QIODevice::OpenMode a3def = QIODevice::ReadWrite;
         ::QIODevice::OpenMode* a3 = &a3def;
        int a3State = 0;
         ::QAbstractSocket::NetworkLayerProtocol a4 = QAbstractSocket::AnyIPProtocol;
         ::QSslSocket *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_mode,
            sipName_protocol,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1tJ1|J1E", &sipSelf, sipType_QSslSocket, &sipCpp, sipType_QString,&a0, &a0State, &a1, sipType_QString,&a2, &a2State, sipType_QIODevice_OpenMode, &a3, &a3State, sipType_QAbstractSocket_NetworkLayerProtocol, &a4))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->connectToHostEncrypted(*a0,a1,*a2,*a3,a4);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(const_cast< ::QString *>(a2),sipType_QString,a2State);
            sipReleaseType(a3,sipType_QIODevice_OpenMode,a3State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_connectToHostEncrypted, doc_QSslSocket_connectToHostEncrypted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_setSocketDescriptor, "setSocketDescriptor(self, sip.voidptr, state: QAbstractSocket.SocketState = QAbstractSocket.ConnectedState, mode: Union[QIODevice.OpenMode, QIODevice.OpenModeFlag] = QIODevice.ReadWrite) -> bool");

extern "C" {static PyObject *meth_QSslSocket_setSocketDescriptor(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_setSocketDescriptor(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::qintptr* a0;
        int a0State = 0;
         ::QAbstractSocket::SocketState a1 = QAbstractSocket::ConnectedState;
         ::QIODevice::OpenMode a2def = QIODevice::ReadWrite;
         ::QIODevice::OpenMode* a2 = &a2def;
        int a2State = 0;
         ::QSslSocket *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_state,
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|EJ1", &sipSelf, sipType_QSslSocket, &sipCpp, sipType_qintptr,&a0, &a0State, sipType_QAbstractSocket_SocketState, &a1, sipType_QIODevice_OpenMode, &a2, &a2State))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QSslSocket::setSocketDescriptor(*a0,a1,*a2) : sipCpp->setSocketDescriptor(*a0,a1,*a2));
            sipReleaseType(a0,sipType_qintptr,a0State);
            sipReleaseType(a2,sipType_QIODevice_OpenMode,a2State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_setSocketDescriptor, doc_QSslSocket_setSocketDescriptor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_mode, "mode(self) -> QSslSocket.SslMode");

extern "C" {static PyObject *meth_QSslSocket_mode(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_mode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
             ::QSslSocket::SslMode sipRes;

            sipRes = sipCpp->mode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QSslSocket_SslMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_mode, doc_QSslSocket_mode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_isEncrypted, "isEncrypted(self) -> bool");

extern "C" {static PyObject *meth_QSslSocket_isEncrypted(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_isEncrypted(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isEncrypted();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_isEncrypted, doc_QSslSocket_isEncrypted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_protocol, "protocol(self) -> QSsl.SslProtocol");

extern "C" {static PyObject *meth_QSslSocket_protocol(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_protocol(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
             ::QSsl::SslProtocol sipRes;

            sipRes = sipCpp->protocol();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QSsl_SslProtocol);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_protocol, doc_QSslSocket_protocol);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_setProtocol, "setProtocol(self, QSsl.SslProtocol)");

extern "C" {static PyObject *meth_QSslSocket_setProtocol(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_setProtocol(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSsl::SslProtocol a0;
         ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QSslSocket, &sipCpp, sipType_QSsl_SslProtocol, &a0))
        {
            sipCpp->setProtocol(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_setProtocol, doc_QSslSocket_setProtocol);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_bytesAvailable, "bytesAvailable(self) -> int");

extern "C" {static PyObject *meth_QSslSocket_bytesAvailable(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_bytesAvailable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
             ::qint64 sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QSslSocket::bytesAvailable() : sipCpp->bytesAvailable());

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_bytesAvailable, doc_QSslSocket_bytesAvailable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_bytesToWrite, "bytesToWrite(self) -> int");

extern "C" {static PyObject *meth_QSslSocket_bytesToWrite(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_bytesToWrite(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
             ::qint64 sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QSslSocket::bytesToWrite() : sipCpp->bytesToWrite());

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_bytesToWrite, doc_QSslSocket_bytesToWrite);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_canReadLine, "canReadLine(self) -> bool");

extern "C" {static PyObject *meth_QSslSocket_canReadLine(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_canReadLine(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QSslSocket::canReadLine() : sipCpp->canReadLine());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_canReadLine, doc_QSslSocket_canReadLine);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_close, "close(self)");

extern "C" {static PyObject *meth_QSslSocket_close(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_close(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp-> ::QSslSocket::close() : sipCpp->close());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_close, doc_QSslSocket_close);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_atEnd, "atEnd(self) -> bool");

extern "C" {static PyObject *meth_QSslSocket_atEnd(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_atEnd(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QSslSocket::atEnd() : sipCpp->atEnd());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_atEnd, doc_QSslSocket_atEnd);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_flush, "flush(self) -> bool");

extern "C" {static PyObject *meth_QSslSocket_flush(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_flush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->flush();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_flush, doc_QSslSocket_flush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_abort, "abort(self)");

extern "C" {static PyObject *meth_QSslSocket_abort(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_abort(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
            sipCpp->abort();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_abort, doc_QSslSocket_abort);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_setLocalCertificate, "setLocalCertificate(self, QSslCertificate)\n"
"setLocalCertificate(self, str, format: QSsl.EncodingFormat = QSsl.Pem)");

extern "C" {static PyObject *meth_QSslSocket_setLocalCertificate(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_setLocalCertificate(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSslCertificate* a0;
         ::QSslSocket *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ9", &sipSelf, sipType_QSslSocket, &sipCpp, sipType_QSslCertificate, &a0))
        {
            sipCpp->setLocalCertificate(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QSsl::EncodingFormat a1 = QSsl::Pem;
         ::QSslSocket *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|E", &sipSelf, sipType_QSslSocket, &sipCpp, sipType_QString,&a0, &a0State, sipType_QSsl_EncodingFormat, &a1))
        {
            sipCpp->setLocalCertificate(*a0,a1);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_setLocalCertificate, doc_QSslSocket_setLocalCertificate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_localCertificate, "localCertificate(self) -> QSslCertificate");

extern "C" {static PyObject *meth_QSslSocket_localCertificate(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_localCertificate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
             ::QSslCertificate*sipRes;

            sipRes = new  ::QSslCertificate(sipCpp->localCertificate());

            return sipConvertFromNewType(sipRes,sipType_QSslCertificate,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_localCertificate, doc_QSslSocket_localCertificate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_peerCertificate, "peerCertificate(self) -> QSslCertificate");

extern "C" {static PyObject *meth_QSslSocket_peerCertificate(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_peerCertificate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
             ::QSslCertificate*sipRes;

            sipRes = new  ::QSslCertificate(sipCpp->peerCertificate());

            return sipConvertFromNewType(sipRes,sipType_QSslCertificate,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_peerCertificate, doc_QSslSocket_peerCertificate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_peerCertificateChain, "peerCertificateChain(self) -> List[QSslCertificate]");

extern "C" {static PyObject *meth_QSslSocket_peerCertificateChain(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_peerCertificateChain(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
            QList< ::QSslCertificate>*sipRes;

            sipRes = new QList< ::QSslCertificate>(sipCpp->peerCertificateChain());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QSslCertificate,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_peerCertificateChain, doc_QSslSocket_peerCertificateChain);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_sessionCipher, "sessionCipher(self) -> QSslCipher");

extern "C" {static PyObject *meth_QSslSocket_sessionCipher(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_sessionCipher(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
             ::QSslCipher*sipRes;

            sipRes = new  ::QSslCipher(sipCpp->sessionCipher());

            return sipConvertFromNewType(sipRes,sipType_QSslCipher,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_sessionCipher, doc_QSslSocket_sessionCipher);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_setPrivateKey, "setPrivateKey(self, QSslKey)\n"
"setPrivateKey(self, str, algorithm: QSsl.KeyAlgorithm = QSsl.Rsa, format: QSsl.EncodingFormat = QSsl.Pem, passPhrase: Union[QByteArray, bytes, bytearray] = QByteArray())");

extern "C" {static PyObject *meth_QSslSocket_setPrivateKey(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_setPrivateKey(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSslKey* a0;
         ::QSslSocket *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ9", &sipSelf, sipType_QSslSocket, &sipCpp, sipType_QSslKey, &a0))
        {
            sipCpp->setPrivateKey(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QSsl::KeyAlgorithm a1 = QSsl::Rsa;
         ::QSsl::EncodingFormat a2 = QSsl::Pem;
        const  ::QByteArray& a3def = QByteArray();
        const  ::QByteArray* a3 = &a3def;
        int a3State = 0;
         ::QSslSocket *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_algorithm,
            sipName_format,
            sipName_passPhrase,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|EEJ1", &sipSelf, sipType_QSslSocket, &sipCpp, sipType_QString,&a0, &a0State, sipType_QSsl_KeyAlgorithm, &a1, sipType_QSsl_EncodingFormat, &a2, sipType_QByteArray, &a3, &a3State))
        {
            sipCpp->setPrivateKey(*a0,a1,a2,*a3);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(const_cast< ::QByteArray *>(a3),sipType_QByteArray,a3State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_setPrivateKey, doc_QSslSocket_setPrivateKey);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_privateKey, "privateKey(self) -> QSslKey");

extern "C" {static PyObject *meth_QSslSocket_privateKey(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_privateKey(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
             ::QSslKey*sipRes;

            sipRes = new  ::QSslKey(sipCpp->privateKey());

            return sipConvertFromNewType(sipRes,sipType_QSslKey,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_privateKey, doc_QSslSocket_privateKey);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_ciphers, "ciphers(self) -> List[QSslCipher]");

extern "C" {static PyObject *meth_QSslSocket_ciphers(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_ciphers(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
            QList< ::QSslCipher>*sipRes;

            sipRes = new QList< ::QSslCipher>(sipCpp->ciphers());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QSslCipher,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_ciphers, doc_QSslSocket_ciphers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_setCiphers, "setCiphers(self, Iterable[QSslCipher])\n"
"setCiphers(self, str)");

extern "C" {static PyObject *meth_QSslSocket_setCiphers(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_setCiphers(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QSslCipher>* a0;
        int a0State = 0;
         ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSslSocket, &sipCpp, sipType_QList_0100QSslCipher,&a0, &a0State))
        {
            sipCpp->setCiphers(*a0);
            sipReleaseType(const_cast<QList< ::QSslCipher> *>(a0),sipType_QList_0100QSslCipher,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSslSocket, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->setCiphers(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_setCiphers, doc_QSslSocket_setCiphers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_setDefaultCiphers, "setDefaultCiphers(Iterable[QSslCipher])");

extern "C" {static PyObject *meth_QSslSocket_setDefaultCiphers(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_setDefaultCiphers(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QSslCipher>* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QList_0100QSslCipher,&a0, &a0State))
        {
             ::QSslSocket::setDefaultCiphers(*a0);
            sipReleaseType(const_cast<QList< ::QSslCipher> *>(a0),sipType_QList_0100QSslCipher,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_setDefaultCiphers, doc_QSslSocket_setDefaultCiphers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_defaultCiphers, "defaultCiphers() -> List[QSslCipher]");

extern "C" {static PyObject *meth_QSslSocket_defaultCiphers(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_defaultCiphers(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QSslCipher>*sipRes;

            sipRes = new QList< ::QSslCipher>( ::QSslSocket::defaultCiphers());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QSslCipher,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_defaultCiphers, doc_QSslSocket_defaultCiphers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_supportedCiphers, "supportedCiphers() -> List[QSslCipher]");

extern "C" {static PyObject *meth_QSslSocket_supportedCiphers(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_supportedCiphers(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QSslCipher>*sipRes;

            sipRes = new QList< ::QSslCipher>( ::QSslSocket::supportedCiphers());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QSslCipher,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_supportedCiphers, doc_QSslSocket_supportedCiphers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_addCaCertificates, "addCaCertificates(self, str, format: QSsl.EncodingFormat = QSsl.Pem, syntax: QRegExp.PatternSyntax = QRegExp.FixedString) -> bool\n"
"addCaCertificates(self, Iterable[QSslCertificate])");

extern "C" {static PyObject *meth_QSslSocket_addCaCertificates(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_addCaCertificates(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QSsl::EncodingFormat a1 = QSsl::Pem;
         ::QRegExp::PatternSyntax a2 = QRegExp::FixedString;
         ::QSslSocket *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
            sipName_syntax,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|EE", &sipSelf, sipType_QSslSocket, &sipCpp, sipType_QString,&a0, &a0State, sipType_QSsl_EncodingFormat, &a1, sipType_QRegExp_PatternSyntax, &a2))
        {
            bool sipRes;

            sipRes = sipCpp->addCaCertificates(*a0,a1,a2);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const QList< ::QSslCertificate>* a0;
        int a0State = 0;
         ::QSslSocket *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1", &sipSelf, sipType_QSslSocket, &sipCpp, sipType_QList_0100QSslCertificate,&a0, &a0State))
        {
            sipCpp->addCaCertificates(*a0);
            sipReleaseType(const_cast<QList< ::QSslCertificate> *>(a0),sipType_QList_0100QSslCertificate,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_addCaCertificates, doc_QSslSocket_addCaCertificates);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_addCaCertificate, "addCaCertificate(self, QSslCertificate)");

extern "C" {static PyObject *meth_QSslSocket_addCaCertificate(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_addCaCertificate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSslCertificate* a0;
         ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QSslSocket, &sipCpp, sipType_QSslCertificate, &a0))
        {
            sipCpp->addCaCertificate(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_addCaCertificate, doc_QSslSocket_addCaCertificate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_setCaCertificates, "setCaCertificates(self, Iterable[QSslCertificate])");

extern "C" {static PyObject *meth_QSslSocket_setCaCertificates(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_setCaCertificates(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QSslCertificate>* a0;
        int a0State = 0;
         ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSslSocket, &sipCpp, sipType_QList_0100QSslCertificate,&a0, &a0State))
        {
            sipCpp->setCaCertificates(*a0);
            sipReleaseType(const_cast<QList< ::QSslCertificate> *>(a0),sipType_QList_0100QSslCertificate,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_setCaCertificates, doc_QSslSocket_setCaCertificates);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_caCertificates, "caCertificates(self) -> List[QSslCertificate]");

extern "C" {static PyObject *meth_QSslSocket_caCertificates(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_caCertificates(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
            QList< ::QSslCertificate>*sipRes;

            sipRes = new QList< ::QSslCertificate>(sipCpp->caCertificates());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QSslCertificate,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_caCertificates, doc_QSslSocket_caCertificates);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_addDefaultCaCertificates, "addDefaultCaCertificates(str, format: QSsl.EncodingFormat = QSsl.Pem, syntax: QRegExp.PatternSyntax = QRegExp.FixedString) -> bool\n"
"addDefaultCaCertificates(Iterable[QSslCertificate])");

extern "C" {static PyObject *meth_QSslSocket_addDefaultCaCertificates(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_addDefaultCaCertificates(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QSsl::EncodingFormat a1 = QSsl::Pem;
         ::QRegExp::PatternSyntax a2 = QRegExp::FixedString;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
            sipName_syntax,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J1|EE", sipType_QString,&a0, &a0State, sipType_QSsl_EncodingFormat, &a1, sipType_QRegExp_PatternSyntax, &a2))
        {
            bool sipRes;

            sipRes =  ::QSslSocket::addDefaultCaCertificates(*a0,a1,a2);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const QList< ::QSslCertificate>* a0;
        int a0State = 0;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "J1", sipType_QList_0100QSslCertificate,&a0, &a0State))
        {
             ::QSslSocket::addDefaultCaCertificates(*a0);
            sipReleaseType(const_cast<QList< ::QSslCertificate> *>(a0),sipType_QList_0100QSslCertificate,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_addDefaultCaCertificates, doc_QSslSocket_addDefaultCaCertificates);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_addDefaultCaCertificate, "addDefaultCaCertificate(QSslCertificate)");

extern "C" {static PyObject *meth_QSslSocket_addDefaultCaCertificate(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_addDefaultCaCertificate(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSslCertificate* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QSslCertificate, &a0))
        {
             ::QSslSocket::addDefaultCaCertificate(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_addDefaultCaCertificate, doc_QSslSocket_addDefaultCaCertificate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_setDefaultCaCertificates, "setDefaultCaCertificates(Iterable[QSslCertificate])");

extern "C" {static PyObject *meth_QSslSocket_setDefaultCaCertificates(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_setDefaultCaCertificates(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QSslCertificate>* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QList_0100QSslCertificate,&a0, &a0State))
        {
             ::QSslSocket::setDefaultCaCertificates(*a0);
            sipReleaseType(const_cast<QList< ::QSslCertificate> *>(a0),sipType_QList_0100QSslCertificate,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_setDefaultCaCertificates, doc_QSslSocket_setDefaultCaCertificates);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_defaultCaCertificates, "defaultCaCertificates() -> List[QSslCertificate]");

extern "C" {static PyObject *meth_QSslSocket_defaultCaCertificates(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_defaultCaCertificates(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QSslCertificate>*sipRes;

            sipRes = new QList< ::QSslCertificate>( ::QSslSocket::defaultCaCertificates());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QSslCertificate,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_defaultCaCertificates, doc_QSslSocket_defaultCaCertificates);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_systemCaCertificates, "systemCaCertificates() -> List[QSslCertificate]");

extern "C" {static PyObject *meth_QSslSocket_systemCaCertificates(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_systemCaCertificates(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QSslCertificate>*sipRes;

            sipRes = new QList< ::QSslCertificate>( ::QSslSocket::systemCaCertificates());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QSslCertificate,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_systemCaCertificates, doc_QSslSocket_systemCaCertificates);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_waitForConnected, "waitForConnected(self, msecs: int = 30000) -> bool");

extern "C" {static PyObject *meth_QSslSocket_waitForConnected(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_waitForConnected(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0 = 30000;
         ::QSslSocket *sipCpp;

        static const char *sipKwdList[] = {
            sipName_msecs,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|i", &sipSelf, sipType_QSslSocket, &sipCpp, &a0))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = (sipSelfWasArg ? sipCpp-> ::QSslSocket::waitForConnected(a0) : sipCpp->waitForConnected(a0));
            Py_END_ALLOW_THREADS

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_waitForConnected, doc_QSslSocket_waitForConnected);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_waitForEncrypted, "waitForEncrypted(self, msecs: int = 30000) -> bool");

extern "C" {static PyObject *meth_QSslSocket_waitForEncrypted(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_waitForEncrypted(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0 = 30000;
         ::QSslSocket *sipCpp;

        static const char *sipKwdList[] = {
            sipName_msecs,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|i", &sipSelf, sipType_QSslSocket, &sipCpp, &a0))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = sipCpp->waitForEncrypted(a0);
            Py_END_ALLOW_THREADS

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_waitForEncrypted, doc_QSslSocket_waitForEncrypted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_waitForReadyRead, "waitForReadyRead(self, msecs: int = 30000) -> bool");

extern "C" {static PyObject *meth_QSslSocket_waitForReadyRead(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_waitForReadyRead(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0 = 30000;
         ::QSslSocket *sipCpp;

        static const char *sipKwdList[] = {
            sipName_msecs,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|i", &sipSelf, sipType_QSslSocket, &sipCpp, &a0))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = (sipSelfWasArg ? sipCpp-> ::QSslSocket::waitForReadyRead(a0) : sipCpp->waitForReadyRead(a0));
            Py_END_ALLOW_THREADS

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_waitForReadyRead, doc_QSslSocket_waitForReadyRead);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_waitForBytesWritten, "waitForBytesWritten(self, msecs: int = 30000) -> bool");

extern "C" {static PyObject *meth_QSslSocket_waitForBytesWritten(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_waitForBytesWritten(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0 = 30000;
         ::QSslSocket *sipCpp;

        static const char *sipKwdList[] = {
            sipName_msecs,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|i", &sipSelf, sipType_QSslSocket, &sipCpp, &a0))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = (sipSelfWasArg ? sipCpp-> ::QSslSocket::waitForBytesWritten(a0) : sipCpp->waitForBytesWritten(a0));
            Py_END_ALLOW_THREADS

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_waitForBytesWritten, doc_QSslSocket_waitForBytesWritten);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_waitForDisconnected, "waitForDisconnected(self, msecs: int = 30000) -> bool");

extern "C" {static PyObject *meth_QSslSocket_waitForDisconnected(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_waitForDisconnected(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0 = 30000;
         ::QSslSocket *sipCpp;

        static const char *sipKwdList[] = {
            sipName_msecs,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|i", &sipSelf, sipType_QSslSocket, &sipCpp, &a0))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = (sipSelfWasArg ? sipCpp-> ::QSslSocket::waitForDisconnected(a0) : sipCpp->waitForDisconnected(a0));
            Py_END_ALLOW_THREADS

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_waitForDisconnected, doc_QSslSocket_waitForDisconnected);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_sslErrors, "sslErrors(self) -> List[QSslError]");

extern "C" {static PyObject *meth_QSslSocket_sslErrors(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_sslErrors(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
            QList< ::QSslError>*sipRes;

            sipRes = new QList< ::QSslError>(sipCpp->sslErrors());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QSslError,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_sslErrors, doc_QSslSocket_sslErrors);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_supportsSsl, "supportsSsl() -> bool");

extern "C" {static PyObject *meth_QSslSocket_supportsSsl(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_supportsSsl(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            bool sipRes;

            sipRes =  ::QSslSocket::supportsSsl();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_supportsSsl, doc_QSslSocket_supportsSsl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_startClientEncryption, "startClientEncryption(self)");

extern "C" {static PyObject *meth_QSslSocket_startClientEncryption(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_startClientEncryption(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
            sipCpp->startClientEncryption();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_startClientEncryption, doc_QSslSocket_startClientEncryption);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_startServerEncryption, "startServerEncryption(self)");

extern "C" {static PyObject *meth_QSslSocket_startServerEncryption(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_startServerEncryption(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
            sipCpp->startServerEncryption();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_startServerEncryption, doc_QSslSocket_startServerEncryption);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_ignoreSslErrors, "ignoreSslErrors(self)\n"
"ignoreSslErrors(self, Iterable[QSslError])");

extern "C" {static PyObject *meth_QSslSocket_ignoreSslErrors(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_ignoreSslErrors(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
            sipCpp->ignoreSslErrors();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const QList< ::QSslError>* a0;
        int a0State = 0;
         ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSslSocket, &sipCpp, sipType_QList_0100QSslError,&a0, &a0State))
        {
            sipCpp->ignoreSslErrors(*a0);
            sipReleaseType(const_cast<QList< ::QSslError> *>(a0),sipType_QList_0100QSslError,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_ignoreSslErrors, doc_QSslSocket_ignoreSslErrors);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_readData, "readData(self, int) -> bytes");

extern "C" {static PyObject *meth_QSslSocket_readData(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_readData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::qint64 a0;
         ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pn", &sipSelf, sipType_QSslSocket, &sipCpp, &a0))
        {
            PyObject * sipRes = SIP_NULLPTR;
            int sipIsErr = 0;

#line 105 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qsslsocket.sip"
        // Return the data read or None if there was an error.
        if (a0 < 0)
        {
            PyErr_SetString(PyExc_ValueError, "maximum length of data to be read cannot be negative");
            sipIsErr = 1;
        }
        else
        {
            char *s = new char[a0];
            qint64 len;
        
            Py_BEGIN_ALLOW_THREADS
        #if defined(SIP_PROTECTED_IS_PUBLIC)
            len = sipSelfWasArg ? sipCpp->QSslSocket::readData(s, a0) : sipCpp->readData(s, a0);
        #else
            len = sipCpp->sipProtectVirt_readData(sipSelfWasArg, s, a0);
        #endif
            Py_END_ALLOW_THREADS
        
            if (len < 0)
            {
                Py_INCREF(Py_None);
                sipRes = Py_None;
            }
            else
            {
                sipRes = SIPBytes_FromStringAndSize(s, len);
        
                if (!sipRes)
                    sipIsErr = 1;
            }
        
            delete[] s;
        }
#line 2257 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSslSocket.cpp"

            if (sipIsErr)
                return 0;

            return sipRes;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_readData, doc_QSslSocket_readData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_writeData, "writeData(self, bytes) -> int");

extern "C" {static PyObject *meth_QSslSocket_writeData(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_writeData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const char* a0;
        SIP_SSIZE_T a1;
         ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pk", &sipSelf, sipType_QSslSocket, &sipCpp, &a0, &a1))
        {
             ::qint64 sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = (sipSelfWasArg ? sipCpp-> ::QSslSocket::writeData(a0,(PY_LONG_LONG)a1) : sipCpp->writeData(a0,(PY_LONG_LONG)a1));
            Py_END_ALLOW_THREADS

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_writeData, doc_QSslSocket_writeData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_peerVerifyMode, "peerVerifyMode(self) -> QSslSocket.PeerVerifyMode");

extern "C" {static PyObject *meth_QSslSocket_peerVerifyMode(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_peerVerifyMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
             ::QSslSocket::PeerVerifyMode sipRes;

            sipRes = sipCpp->peerVerifyMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QSslSocket_PeerVerifyMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_peerVerifyMode, doc_QSslSocket_peerVerifyMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_setPeerVerifyMode, "setPeerVerifyMode(self, QSslSocket.PeerVerifyMode)");

extern "C" {static PyObject *meth_QSslSocket_setPeerVerifyMode(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_setPeerVerifyMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSslSocket::PeerVerifyMode a0;
         ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QSslSocket, &sipCpp, sipType_QSslSocket_PeerVerifyMode, &a0))
        {
            sipCpp->setPeerVerifyMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_setPeerVerifyMode, doc_QSslSocket_setPeerVerifyMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_peerVerifyDepth, "peerVerifyDepth(self) -> int");

extern "C" {static PyObject *meth_QSslSocket_peerVerifyDepth(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_peerVerifyDepth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->peerVerifyDepth();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_peerVerifyDepth, doc_QSslSocket_peerVerifyDepth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_setPeerVerifyDepth, "setPeerVerifyDepth(self, int)");

extern "C" {static PyObject *meth_QSslSocket_setPeerVerifyDepth(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_setPeerVerifyDepth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QSslSocket, &sipCpp, &a0))
        {
            sipCpp->setPeerVerifyDepth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_setPeerVerifyDepth, doc_QSslSocket_setPeerVerifyDepth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_setReadBufferSize, "setReadBufferSize(self, int)");

extern "C" {static PyObject *meth_QSslSocket_setReadBufferSize(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_setReadBufferSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::qint64 a0;
         ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bn", &sipSelf, sipType_QSslSocket, &sipCpp, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QSslSocket::setReadBufferSize(a0) : sipCpp->setReadBufferSize(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_setReadBufferSize, doc_QSslSocket_setReadBufferSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_encryptedBytesAvailable, "encryptedBytesAvailable(self) -> int");

extern "C" {static PyObject *meth_QSslSocket_encryptedBytesAvailable(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_encryptedBytesAvailable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
             ::qint64 sipRes;

            sipRes = sipCpp->encryptedBytesAvailable();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_encryptedBytesAvailable, doc_QSslSocket_encryptedBytesAvailable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_encryptedBytesToWrite, "encryptedBytesToWrite(self) -> int");

extern "C" {static PyObject *meth_QSslSocket_encryptedBytesToWrite(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_encryptedBytesToWrite(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
             ::qint64 sipRes;

            sipRes = sipCpp->encryptedBytesToWrite();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_encryptedBytesToWrite, doc_QSslSocket_encryptedBytesToWrite);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_sslConfiguration, "sslConfiguration(self) -> QSslConfiguration");

extern "C" {static PyObject *meth_QSslSocket_sslConfiguration(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_sslConfiguration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
             ::QSslConfiguration*sipRes;

            sipRes = new  ::QSslConfiguration(sipCpp->sslConfiguration());

            return sipConvertFromNewType(sipRes,sipType_QSslConfiguration,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_sslConfiguration, doc_QSslSocket_sslConfiguration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_setSslConfiguration, "setSslConfiguration(self, QSslConfiguration)");

extern "C" {static PyObject *meth_QSslSocket_setSslConfiguration(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_setSslConfiguration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSslConfiguration* a0;
         ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QSslSocket, &sipCpp, sipType_QSslConfiguration, &a0))
        {
            sipCpp->setSslConfiguration(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_setSslConfiguration, doc_QSslSocket_setSslConfiguration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_setSocketOption, "setSocketOption(self, QAbstractSocket.SocketOption, Any)");

extern "C" {static PyObject *meth_QSslSocket_setSocketOption(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_setSocketOption(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QAbstractSocket::SocketOption a0;
        const  ::QVariant* a1;
        int a1State = 0;
         ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEJ1", &sipSelf, sipType_QSslSocket, &sipCpp, sipType_QAbstractSocket_SocketOption, &a0, sipType_QVariant, &a1, &a1State))
        {
            (sipSelfWasArg ? sipCpp-> ::QSslSocket::setSocketOption(a0,*a1) : sipCpp->setSocketOption(a0,*a1));
            sipReleaseType(const_cast< ::QVariant *>(a1),sipType_QVariant,a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_setSocketOption, doc_QSslSocket_setSocketOption);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_socketOption, "socketOption(self, QAbstractSocket.SocketOption) -> Any");

extern "C" {static PyObject *meth_QSslSocket_socketOption(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_socketOption(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QAbstractSocket::SocketOption a0;
         ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QSslSocket, &sipCpp, sipType_QAbstractSocket_SocketOption, &a0))
        {
             ::QVariant*sipRes;

            sipRes = new  ::QVariant((sipSelfWasArg ? sipCpp-> ::QSslSocket::socketOption(a0) : sipCpp->socketOption(a0)));

            return sipConvertFromNewType(sipRes,sipType_QVariant,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_socketOption, doc_QSslSocket_socketOption);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_peerVerifyName, "peerVerifyName(self) -> str");

extern "C" {static PyObject *meth_QSslSocket_peerVerifyName(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_peerVerifyName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->peerVerifyName());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_peerVerifyName, doc_QSslSocket_peerVerifyName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_setPeerVerifyName, "setPeerVerifyName(self, str)");

extern "C" {static PyObject *meth_QSslSocket_setPeerVerifyName(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_setPeerVerifyName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSslSocket, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->setPeerVerifyName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_setPeerVerifyName, doc_QSslSocket_setPeerVerifyName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_resume, "resume(self)");

extern "C" {static PyObject *meth_QSslSocket_resume(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_resume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
            Py_BEGIN_ALLOW_THREADS
            (sipSelfWasArg ? sipCpp-> ::QSslSocket::resume() : sipCpp->resume());
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_resume, doc_QSslSocket_resume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_connectToHost, "connectToHost(self, str, int, mode: Union[QIODevice.OpenMode, QIODevice.OpenModeFlag] = QIODevice.ReadWrite, protocol: QAbstractSocket.NetworkLayerProtocol = QAbstractSocket.AnyIPProtocol)");

extern "C" {static PyObject *meth_QSslSocket_connectToHost(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_connectToHost(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QString* a0;
        int a0State = 0;
         ::quint16 a1;
         ::QIODevice::OpenMode a2def = QIODevice::ReadWrite;
         ::QIODevice::OpenMode* a2 = &a2def;
        int a2State = 0;
         ::QAbstractSocket::NetworkLayerProtocol a3 = QAbstractSocket::AnyIPProtocol;
         ::QSslSocket *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_mode,
            sipName_protocol,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1t|J1E", &sipSelf, sipType_QSslSocket, &sipCpp, sipType_QString,&a0, &a0State, &a1, sipType_QIODevice_OpenMode, &a2, &a2State, sipType_QAbstractSocket_NetworkLayerProtocol, &a3))
        {
            Py_BEGIN_ALLOW_THREADS
            (sipSelfWasArg ? sipCpp-> ::QSslSocket::connectToHost(*a0,a1,*a2,a3) : sipCpp->connectToHost(*a0,a1,*a2,a3));
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(a2,sipType_QIODevice_OpenMode,a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_connectToHost, doc_QSslSocket_connectToHost);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_disconnectFromHost, "disconnectFromHost(self)");

extern "C" {static PyObject *meth_QSslSocket_disconnectFromHost(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_disconnectFromHost(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
            Py_BEGIN_ALLOW_THREADS
            (sipSelfWasArg ? sipCpp-> ::QSslSocket::disconnectFromHost() : sipCpp->disconnectFromHost());
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_disconnectFromHost, doc_QSslSocket_disconnectFromHost);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_sslLibraryVersionNumber, "sslLibraryVersionNumber() -> int");

extern "C" {static PyObject *meth_QSslSocket_sslLibraryVersionNumber(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_sslLibraryVersionNumber(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            long sipRes;

            sipRes =  ::QSslSocket::sslLibraryVersionNumber();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_sslLibraryVersionNumber, doc_QSslSocket_sslLibraryVersionNumber);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_sslLibraryVersionString, "sslLibraryVersionString() -> str");

extern "C" {static PyObject *meth_QSslSocket_sslLibraryVersionString(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_sslLibraryVersionString(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
             ::QString*sipRes;

            sipRes = new  ::QString( ::QSslSocket::sslLibraryVersionString());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_sslLibraryVersionString, doc_QSslSocket_sslLibraryVersionString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_setLocalCertificateChain, "setLocalCertificateChain(self, Iterable[QSslCertificate])");

extern "C" {static PyObject *meth_QSslSocket_setLocalCertificateChain(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_setLocalCertificateChain(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QSslCertificate>* a0;
        int a0State = 0;
         ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSslSocket, &sipCpp, sipType_QList_0100QSslCertificate,&a0, &a0State))
        {
            sipCpp->setLocalCertificateChain(*a0);
            sipReleaseType(const_cast<QList< ::QSslCertificate> *>(a0),sipType_QList_0100QSslCertificate,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_setLocalCertificateChain, doc_QSslSocket_setLocalCertificateChain);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_localCertificateChain, "localCertificateChain(self) -> List[QSslCertificate]");

extern "C" {static PyObject *meth_QSslSocket_localCertificateChain(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_localCertificateChain(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
            QList< ::QSslCertificate>*sipRes;

            sipRes = new QList< ::QSslCertificate>(sipCpp->localCertificateChain());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QSslCertificate,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_localCertificateChain, doc_QSslSocket_localCertificateChain);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_sessionProtocol, "sessionProtocol(self) -> QSsl.SslProtocol");

extern "C" {static PyObject *meth_QSslSocket_sessionProtocol(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_sessionProtocol(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
             ::QSsl::SslProtocol sipRes;

            sipRes = sipCpp->sessionProtocol();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QSsl_SslProtocol);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_sessionProtocol, doc_QSslSocket_sessionProtocol);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_sslLibraryBuildVersionNumber, "sslLibraryBuildVersionNumber() -> int");

extern "C" {static PyObject *meth_QSslSocket_sslLibraryBuildVersionNumber(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_sslLibraryBuildVersionNumber(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            long sipRes;

            sipRes =  ::QSslSocket::sslLibraryBuildVersionNumber();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_sslLibraryBuildVersionNumber, doc_QSslSocket_sslLibraryBuildVersionNumber);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_sslLibraryBuildVersionString, "sslLibraryBuildVersionString() -> str");

extern "C" {static PyObject *meth_QSslSocket_sslLibraryBuildVersionString(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_sslLibraryBuildVersionString(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
             ::QString*sipRes;

            sipRes = new  ::QString( ::QSslSocket::sslLibraryBuildVersionString());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_sslLibraryBuildVersionString, doc_QSslSocket_sslLibraryBuildVersionString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_ocspResponses, "ocspResponses(self) -> List[QOcspResponse]");

extern "C" {static PyObject *meth_QSslSocket_ocspResponses(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_ocspResponses(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
            QVector< ::QOcspResponse>*sipRes;

            sipRes = new QVector< ::QOcspResponse>(sipCpp->ocspResponses());

            return sipConvertFromNewType(sipRes,sipType_QVector_0100QOcspResponse,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_ocspResponses, doc_QSslSocket_ocspResponses);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslSocket_sslHandshakeErrors, "sslHandshakeErrors(self) -> List[QSslError]");

extern "C" {static PyObject *meth_QSslSocket_sslHandshakeErrors(PyObject *, PyObject *);}
static PyObject *meth_QSslSocket_sslHandshakeErrors(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSslSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslSocket, &sipCpp))
        {
            QList< ::QSslError>*sipRes;

            sipRes = new QList< ::QSslError>(sipCpp->sslHandshakeErrors());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QSslError,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslSocket, sipName_sslHandshakeErrors, doc_QSslSocket_sslHandshakeErrors);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QSslSocket(void *, const sipTypeDef *);}
static void *cast_QSslSocket(void *sipCppV, const sipTypeDef *targetType)
{
     ::QSslSocket *sipCpp = reinterpret_cast< ::QSslSocket *>(sipCppV);

    if (targetType == sipType_QTcpSocket)
        return static_cast< ::QTcpSocket *>(sipCpp);

    if (targetType == sipType_QAbstractSocket)
        return static_cast< ::QAbstractSocket *>(sipCpp);

    if (targetType == sipType_QIODevice)
        return static_cast< ::QIODevice *>(sipCpp);

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_QSslSocket(void *, int);}
static void release_QSslSocket(void *sipCppV, int)
{
     ::QSslSocket *sipCpp = reinterpret_cast< ::QSslSocket *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QSslSocket(Py_ssize_t);}
static void *array_QSslSocket(Py_ssize_t sipNrElem)
{
    return new  ::QSslSocket[sipNrElem];
}


extern "C" {static void dealloc_QSslSocket(sipSimpleWrapper *);}
static void dealloc_QSslSocket(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQSslSocket *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QSslSocket(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QSslSocket(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QSslSocket(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQSslSocket *sipCpp = SIP_NULLPTR;

    {
         ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQSslSocket(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QSslSocket[] = {{135, 255, 1}};


static PyMethodDef methods_QSslSocket[] = {
    {SIP_MLNAME_CAST(sipName_abort), meth_QSslSocket_abort, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_abort)},
    {SIP_MLNAME_CAST(sipName_addCaCertificate), meth_QSslSocket_addCaCertificate, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_addCaCertificate)},
    {SIP_MLNAME_CAST(sipName_addCaCertificates), SIP_MLMETH_CAST(meth_QSslSocket_addCaCertificates), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QSslSocket_addCaCertificates)},
    {SIP_MLNAME_CAST(sipName_addDefaultCaCertificate), meth_QSslSocket_addDefaultCaCertificate, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_addDefaultCaCertificate)},
    {SIP_MLNAME_CAST(sipName_addDefaultCaCertificates), SIP_MLMETH_CAST(meth_QSslSocket_addDefaultCaCertificates), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QSslSocket_addDefaultCaCertificates)},
    {SIP_MLNAME_CAST(sipName_atEnd), meth_QSslSocket_atEnd, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_atEnd)},
    {SIP_MLNAME_CAST(sipName_bytesAvailable), meth_QSslSocket_bytesAvailable, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_bytesAvailable)},
    {SIP_MLNAME_CAST(sipName_bytesToWrite), meth_QSslSocket_bytesToWrite, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_bytesToWrite)},
    {SIP_MLNAME_CAST(sipName_caCertificates), meth_QSslSocket_caCertificates, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_caCertificates)},
    {SIP_MLNAME_CAST(sipName_canReadLine), meth_QSslSocket_canReadLine, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_canReadLine)},
    {SIP_MLNAME_CAST(sipName_ciphers), meth_QSslSocket_ciphers, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_ciphers)},
    {SIP_MLNAME_CAST(sipName_close), meth_QSslSocket_close, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_close)},
    {SIP_MLNAME_CAST(sipName_connectToHost), SIP_MLMETH_CAST(meth_QSslSocket_connectToHost), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QSslSocket_connectToHost)},
    {SIP_MLNAME_CAST(sipName_connectToHostEncrypted), SIP_MLMETH_CAST(meth_QSslSocket_connectToHostEncrypted), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QSslSocket_connectToHostEncrypted)},
    {SIP_MLNAME_CAST(sipName_defaultCaCertificates), meth_QSslSocket_defaultCaCertificates, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_defaultCaCertificates)},
    {SIP_MLNAME_CAST(sipName_defaultCiphers), meth_QSslSocket_defaultCiphers, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_defaultCiphers)},
    {SIP_MLNAME_CAST(sipName_disconnectFromHost), meth_QSslSocket_disconnectFromHost, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_disconnectFromHost)},
    {SIP_MLNAME_CAST(sipName_encryptedBytesAvailable), meth_QSslSocket_encryptedBytesAvailable, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_encryptedBytesAvailable)},
    {SIP_MLNAME_CAST(sipName_encryptedBytesToWrite), meth_QSslSocket_encryptedBytesToWrite, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_encryptedBytesToWrite)},
    {SIP_MLNAME_CAST(sipName_flush), meth_QSslSocket_flush, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_flush)},
    {SIP_MLNAME_CAST(sipName_ignoreSslErrors), meth_QSslSocket_ignoreSslErrors, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_ignoreSslErrors)},
    {SIP_MLNAME_CAST(sipName_isEncrypted), meth_QSslSocket_isEncrypted, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_isEncrypted)},
    {SIP_MLNAME_CAST(sipName_localCertificate), meth_QSslSocket_localCertificate, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_localCertificate)},
    {SIP_MLNAME_CAST(sipName_localCertificateChain), meth_QSslSocket_localCertificateChain, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_localCertificateChain)},
    {SIP_MLNAME_CAST(sipName_mode), meth_QSslSocket_mode, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_mode)},
    {SIP_MLNAME_CAST(sipName_ocspResponses), meth_QSslSocket_ocspResponses, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_ocspResponses)},
    {SIP_MLNAME_CAST(sipName_peerCertificate), meth_QSslSocket_peerCertificate, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_peerCertificate)},
    {SIP_MLNAME_CAST(sipName_peerCertificateChain), meth_QSslSocket_peerCertificateChain, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_peerCertificateChain)},
    {SIP_MLNAME_CAST(sipName_peerVerifyDepth), meth_QSslSocket_peerVerifyDepth, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_peerVerifyDepth)},
    {SIP_MLNAME_CAST(sipName_peerVerifyMode), meth_QSslSocket_peerVerifyMode, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_peerVerifyMode)},
    {SIP_MLNAME_CAST(sipName_peerVerifyName), meth_QSslSocket_peerVerifyName, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_peerVerifyName)},
    {SIP_MLNAME_CAST(sipName_privateKey), meth_QSslSocket_privateKey, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_privateKey)},
    {SIP_MLNAME_CAST(sipName_protocol), meth_QSslSocket_protocol, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_protocol)},
    {SIP_MLNAME_CAST(sipName_readData), meth_QSslSocket_readData, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_readData)},
    {SIP_MLNAME_CAST(sipName_resume), meth_QSslSocket_resume, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_resume)},
    {SIP_MLNAME_CAST(sipName_sessionCipher), meth_QSslSocket_sessionCipher, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_sessionCipher)},
    {SIP_MLNAME_CAST(sipName_sessionProtocol), meth_QSslSocket_sessionProtocol, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_sessionProtocol)},
    {SIP_MLNAME_CAST(sipName_setCaCertificates), meth_QSslSocket_setCaCertificates, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_setCaCertificates)},
    {SIP_MLNAME_CAST(sipName_setCiphers), meth_QSslSocket_setCiphers, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_setCiphers)},
    {SIP_MLNAME_CAST(sipName_setDefaultCaCertificates), meth_QSslSocket_setDefaultCaCertificates, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_setDefaultCaCertificates)},
    {SIP_MLNAME_CAST(sipName_setDefaultCiphers), meth_QSslSocket_setDefaultCiphers, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_setDefaultCiphers)},
    {SIP_MLNAME_CAST(sipName_setLocalCertificate), SIP_MLMETH_CAST(meth_QSslSocket_setLocalCertificate), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QSslSocket_setLocalCertificate)},
    {SIP_MLNAME_CAST(sipName_setLocalCertificateChain), meth_QSslSocket_setLocalCertificateChain, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_setLocalCertificateChain)},
    {SIP_MLNAME_CAST(sipName_setPeerVerifyDepth), meth_QSslSocket_setPeerVerifyDepth, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_setPeerVerifyDepth)},
    {SIP_MLNAME_CAST(sipName_setPeerVerifyMode), meth_QSslSocket_setPeerVerifyMode, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_setPeerVerifyMode)},
    {SIP_MLNAME_CAST(sipName_setPeerVerifyName), meth_QSslSocket_setPeerVerifyName, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_setPeerVerifyName)},
    {SIP_MLNAME_CAST(sipName_setPrivateKey), SIP_MLMETH_CAST(meth_QSslSocket_setPrivateKey), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QSslSocket_setPrivateKey)},
    {SIP_MLNAME_CAST(sipName_setProtocol), meth_QSslSocket_setProtocol, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_setProtocol)},
    {SIP_MLNAME_CAST(sipName_setReadBufferSize), meth_QSslSocket_setReadBufferSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_setReadBufferSize)},
    {SIP_MLNAME_CAST(sipName_setSocketDescriptor), SIP_MLMETH_CAST(meth_QSslSocket_setSocketDescriptor), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QSslSocket_setSocketDescriptor)},
    {SIP_MLNAME_CAST(sipName_setSocketOption), meth_QSslSocket_setSocketOption, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_setSocketOption)},
    {SIP_MLNAME_CAST(sipName_setSslConfiguration), meth_QSslSocket_setSslConfiguration, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_setSslConfiguration)},
    {SIP_MLNAME_CAST(sipName_socketOption), meth_QSslSocket_socketOption, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_socketOption)},
    {SIP_MLNAME_CAST(sipName_sslConfiguration), meth_QSslSocket_sslConfiguration, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_sslConfiguration)},
    {SIP_MLNAME_CAST(sipName_sslErrors), meth_QSslSocket_sslErrors, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_sslErrors)},
    {SIP_MLNAME_CAST(sipName_sslHandshakeErrors), meth_QSslSocket_sslHandshakeErrors, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_sslHandshakeErrors)},
    {SIP_MLNAME_CAST(sipName_sslLibraryBuildVersionNumber), meth_QSslSocket_sslLibraryBuildVersionNumber, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_sslLibraryBuildVersionNumber)},
    {SIP_MLNAME_CAST(sipName_sslLibraryBuildVersionString), meth_QSslSocket_sslLibraryBuildVersionString, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_sslLibraryBuildVersionString)},
    {SIP_MLNAME_CAST(sipName_sslLibraryVersionNumber), meth_QSslSocket_sslLibraryVersionNumber, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_sslLibraryVersionNumber)},
    {SIP_MLNAME_CAST(sipName_sslLibraryVersionString), meth_QSslSocket_sslLibraryVersionString, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_sslLibraryVersionString)},
    {SIP_MLNAME_CAST(sipName_startClientEncryption), meth_QSslSocket_startClientEncryption, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_startClientEncryption)},
    {SIP_MLNAME_CAST(sipName_startServerEncryption), meth_QSslSocket_startServerEncryption, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_startServerEncryption)},
    {SIP_MLNAME_CAST(sipName_supportedCiphers), meth_QSslSocket_supportedCiphers, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_supportedCiphers)},
    {SIP_MLNAME_CAST(sipName_supportsSsl), meth_QSslSocket_supportsSsl, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_supportsSsl)},
    {SIP_MLNAME_CAST(sipName_systemCaCertificates), meth_QSslSocket_systemCaCertificates, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_systemCaCertificates)},
    {SIP_MLNAME_CAST(sipName_waitForBytesWritten), SIP_MLMETH_CAST(meth_QSslSocket_waitForBytesWritten), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QSslSocket_waitForBytesWritten)},
    {SIP_MLNAME_CAST(sipName_waitForConnected), SIP_MLMETH_CAST(meth_QSslSocket_waitForConnected), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QSslSocket_waitForConnected)},
    {SIP_MLNAME_CAST(sipName_waitForDisconnected), SIP_MLMETH_CAST(meth_QSslSocket_waitForDisconnected), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QSslSocket_waitForDisconnected)},
    {SIP_MLNAME_CAST(sipName_waitForEncrypted), SIP_MLMETH_CAST(meth_QSslSocket_waitForEncrypted), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QSslSocket_waitForEncrypted)},
    {SIP_MLNAME_CAST(sipName_waitForReadyRead), SIP_MLMETH_CAST(meth_QSslSocket_waitForReadyRead), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QSslSocket_waitForReadyRead)},
    {SIP_MLNAME_CAST(sipName_writeData), meth_QSslSocket_writeData, METH_VARARGS, SIP_MLDOC_CAST(doc_QSslSocket_writeData)}
};

static sipEnumMemberDef enummembers_QSslSocket[] = {
    {sipName_AutoVerifyPeer, static_cast<int>( ::QSslSocket::AutoVerifyPeer), 132},
    {sipName_QueryPeer, static_cast<int>( ::QSslSocket::QueryPeer), 132},
    {sipName_SslClientMode, static_cast<int>( ::QSslSocket::SslClientMode), 133},
    {sipName_SslServerMode, static_cast<int>( ::QSslSocket::SslServerMode), 133},
    {sipName_UnencryptedMode, static_cast<int>( ::QSslSocket::UnencryptedMode), 133},
    {sipName_VerifyNone, static_cast<int>( ::QSslSocket::VerifyNone), 132},
    {sipName_VerifyPeer, static_cast<int>( ::QSslSocket::VerifyPeer), 132},
};

PyDoc_STRVAR(doc_QSslSocket, "\1QSslSocket(parent: QObject = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QSslSocket[] = {
    {"newSessionTicketReceived()", "\1newSessionTicketReceived(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"encryptedBytesWritten(qint64)", "\1encryptedBytesWritten(self, int)", SIP_NULLPTR, SIP_NULLPTR},
    {"peerVerifyError(QSslError)", "\1peerVerifyError(self, QSslError)", SIP_NULLPTR, SIP_NULLPTR},
    {"preSharedKeyAuthenticationRequired(QSslPreSharedKeyAuthenticator*)", "\1preSharedKeyAuthenticationRequired(self, QSslPreSharedKeyAuthenticator)", SIP_NULLPTR, SIP_NULLPTR},
    {"modeChanged(QSslSocket::SslMode)", "\1modeChanged(self, QSslSocket.SslMode)", SIP_NULLPTR, SIP_NULLPTR},
    {"encrypted()", "\1encrypted(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"sslErrors(QList<QSslError>)", "\1sslErrors(self, Iterable[QSslError])", &methods_QSslSocket[54], SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QSslSocket = {
    & ::QSslSocket::staticMetaObject,
    0,
    signals_QSslSocket,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtNetwork_QSslSocket = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QSslSocket,
        {SIP_NULLPTR},
        &plugin_QSslSocket
    },
    {
        sipNameNr_QSslSocket,
        {0, 0, 1},
        71, methods_QSslSocket,
        7, enummembers_QSslSocket,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QSslSocket,
    -1,
    -1,
    supers_QSslSocket,
    SIP_NULLPTR,
    init_type_QSslSocket,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QSslSocket,
    SIP_NULLPTR,
    array_QSslSocket,
    SIP_NULLPTR,
    release_QSslSocket,
    cast_QSslSocket,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
